==> qtwebengine-opensource-src_5.12.8+dfsg.orig.tar.xz: qtwebengine-everywhere-src-5.12.8/src/3rdparty/chromium/components/services/unzip/public/cpp/test_unzip_service.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_
#define COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_

#include <memory>

#include "base/macros.h"
#include "components/services/unzip/public/interfaces/unzipper.mojom.h"
#include "mojo/public/cpp/bindings/binding.h"
#include "services/service_manager/public/cpp/service.h"

namespace unzip {

// An implementation of the UnzipService that closes the connection when
// a call is made on the Unzipper interface.
// Can be used with a TestConnectorFactory to simulate crashes in the service
// while processing a call.
class CrashyUnzipService : public service_manager::Service,
                           public mojom::Unzipper {
 public:
  CrashyUnzipService();
  ~CrashyUnzipService() override;

  // service_manager::Service:
  void OnStart() override;
  void OnBindInterface(const service_manager::BindSourceInfo& source_info,
                       const std::string& interface_name,
                       mojo::ScopedMessagePipeHandle interface_pipe) override;

  // unzip::mojom::Unzipper:
  void Unzip(base::File zip_file,
             filesystem::mojom::DirectoryPtr output_dir,
             UnzipCallback callback) override;
  void UnzipWithFilter(base::File zip_file,
                       filesystem::mojom::DirectoryPtr output_dir,
                       mojom::UnzipFilterPtr filter,
                       UnzipWithFilterCallback callback) override;

 private:
  std::unique_ptr<mojo::Binding<mojom::Unzipper>> unzipper_binding_;

  DISALLOW_COPY_AND_ASSIGN(CrashyUnzipService);
};

}  // namespace unzip

#endif  // COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_

==> qtwebengine-opensource-src_5.14.2+dfsg1.orig.tar.xz: qtwebengine-everywhere-src-5.14.2/src/3rdparty/chromium/components/services/unzip/public/cpp/test_unzip_service.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_
#define COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_

#include <memory>

#include "base/macros.h"
#include "components/services/unzip/public/mojom/unzipper.mojom.h"
#include "mojo/public/cpp/bindings/binding.h"
#include "services/service_manager/public/cpp/service.h"
#include "services/service_manager/public/cpp/service_binding.h"

namespace unzip {

// An implementation of the UnzipService that closes the connection when
// a call is made on the Unzipper interface.
// Can be used with a TestConnectorFactory to simulate crashes in the service
// while processing a call.
class CrashyUnzipService : public service_manager::Service,
                           public mojom::Unzipper {
 public:
  explicit CrashyUnzipService(service_manager::mojom::ServiceRequest request);
  ~CrashyUnzipService() override;

  // service_manager::Service:
  void OnBindInterface(const service_manager::BindSourceInfo& source_info,
                       const std::string& interface_name,
                       mojo::ScopedMessagePipeHandle interface_pipe) override;

  // unzip::mojom::Unzipper:
  void Unzip(base::File zip_file,
             filesystem::mojom::DirectoryPtr output_dir,
             UnzipCallback callback) override;
  void UnzipWithFilter(base::File zip_file,
                       filesystem::mojom::DirectoryPtr output_dir,
                       mojom::UnzipFilterPtr filter,
                       UnzipWithFilterCallback callback) override;

 private:
  service_manager::ServiceBinding binding_;
  std::unique_ptr<mojo::Binding<mojom::Unzipper>> unzipper_binding_;

  DISALLOW_COPY_AND_ASSIGN(CrashyUnzipService);
};

}  // namespace unzip

#endif  // COMPONENTS_SERVICES_UNZIP_PUBLIC_CPP_TEST_UNZIP_SERVICE_H_
